<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:tei="http://www.tei-c.org/ns/1.0"
    xpath-default-namespace="http://www.tei-c.org/ns/1.0"
    exclude-result-prefixes="xs" version="2.0">

    <xsl:template match="/">
        <html>
            <head>
                <title>Hamlet</title>
                <style type="text/css">
                    body{
                        font-family:Trebuchet MS;
                        font-size:14pt;
                    }
                    div.floating {
                    float: right;
                    display: block;
                    background-color: #C0C0C0;
                    font-size: smaller;
                    }
                    
                </style>
            </head>
            <body>
                <!-- Title -->
                <h1
                    style="border: 1px solid black; background-color: black; color: #eeeeee; padding: 30px; text-align: center; width: 100%;">
                    <xsl:value-of select="//text/body/div/head[1]"/>
                </h1>

                <div style="max-width: 80%; margin: auto;">
                    <!-- Page images as thumbnails -->
                    <xsl:for-each select="//pb">
                        <xsl:variable name="file" select="substring-after(@facs, ':')"/>
                        <a href="#{$file}">
                            <img src="http://firstfolio.bodleian.ox.ac.uk/page-cropped/{$file}"
                                title="{$file}" width="100"/>
                        </a>
                    </xsl:for-each>

                    <!-- List of characters -->
                    <ol>
                        <xsl:for-each select="//person">
                            <xsl:variable name="pid" select="concat('#',@xml:id)"/>
                            <li>
                                <xsl:choose>
                                    <xsl:when test="sex/@value='2'">
                                        <span style="color: red;">
                                            <xsl:value-of select="persName[1]"/>
                                        </span>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="persName[1]"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:text>: </xsl:text>
                                <xsl:value-of select="count(//sp[@who=$pid])"/>
                                <xsl:text>/</xsl:text>
                                <xsl:value-of select="count(//sp[@who=$pid]//l)"/>
                            </li>
                        </xsl:for-each>
                    </ol>

                    <!-- Text of the play -->
                    <xsl:apply-templates select="//text"/>
                </div>
            </body>
        </html>
    </xsl:template>

    <xsl:template match="head">
        <h3>
            <xsl:value-of select="."/>
        </h3>
    </xsl:template>

    <xsl:template match="div[@type='play']/head[1]">
        <h1 style="font-variant: italic; color: green;">
            <xsl:value-of select="."/>
        </h1>
    </xsl:template>

    <xsl:template match="div[@type='act']/div[@type='scene']/head[1]">
        <h2 style="font-variant: italic; color: green;">
            <xsl:value-of select="."/>
        </h2>
    </xsl:template>

    <xsl:template match="l">
        <xsl:apply-templates/>
        <br/>
    </xsl:template>

    <xsl:template match="speaker">
        <i>
            <xsl:value-of select="."/>
        </i>
        <br/>
    </xsl:template>

    <xsl:template match="sp">
        <p style="margin-top: 1em;">
            <xsl:apply-templates/>
        </p>
    </xsl:template>

    <xsl:template match="fw"/>

    <xsl:template match="pb">
        <xsl:variable name="file" select="substring-after(@facs, ':')"/>
        <a name="{$file}" title="{$file}"/>
        <div class="floating">
            Page <xsl:value-of select="@n"/>
            <br/>
            <img src="http://firstfolio.bodleian.ox.ac.uk/page-cropped/{$file}"
                title="{$file}" width="450"/>
        </div>
        
    </xsl:template>


    <xsl:template match="p">
        <p style="margin-top: 1em;">
            <xsl:apply-templates/>
        </p>
    </xsl:template>

</xsl:stylesheet>
